==> wildfly-dist-10.0.0.Final-src.zip: wildfly-10.0.0.Final-src/clustering/server/src/main/java/org/wildfly/clustering/server/singleton/ServiceNameExternalizer.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2013, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.wildfly.clustering.server.singleton;

import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;

import org.jboss.msc.service.ServiceName;
import org.wildfly.clustering.marshalling.Externalizer;

/**
 * {@link Externalizer} for a {@link ServiceName}.
 * @author Paul Ferraro
 */
public class ServiceNameExternalizer implements Externalizer<ServiceName> {

    @Override
    public void writeObject(ObjectOutput output, ServiceName name) throws IOException {
        output.writeUTF(name.getCanonicalName());
    }

    @Override
    public ServiceName readObject(ObjectInput input) throws IOException {
        return ServiceName.parse(input.readUTF());
    }

    @Override
    public Class<ServiceName> getTargetClass() {
        return ServiceName.class;
    }
}

==> wildfly-dist-11.0.0.Final-src.zip: wildfly-11.0.0.Final-src/clustering/server/src/main/java/org/wildfly/clustering/server/singleton/ServiceNameExternalizer.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2013, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.wildfly.clustering.server.singleton;

import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;

import org.jboss.msc.service.ServiceName;
import org.kohsuke.MetaInfServices;
import org.wildfly.clustering.infinispan.spi.persistence.KeyFormat;
import org.wildfly.clustering.infinispan.spi.persistence.SimpleKeyFormat;
import org.wildfly.clustering.marshalling.Externalizer;

/**
 * {@link Externalizer} for a {@link ServiceName}.
 * @author Paul Ferraro
 */
@MetaInfServices({ Externalizer.class, KeyFormat.class })
public class ServiceNameExternalizer extends SimpleKeyFormat<ServiceName> implements Externalizer<ServiceName> {

    public ServiceNameExternalizer() {
        super(ServiceName.class, ServiceName::parse, ServiceName::getCanonicalName);
    }

    @Override
    public void writeObject(ObjectOutput output, ServiceName name) throws IOException {
        output.writeUTF(name.getCanonicalName());
    }

    @Override
    public ServiceName readObject(ObjectInput input) throws IOException {
        return ServiceName.parse(input.readUTF());
    }
}
